@@ -8,7 +8,7 @@ def log_init(level):
     are in other projects or in our own project.
 
     """
-    log = logging.getLogger()
+    log = logging.getLogger("evasion")
     hdlr = logging.StreamHandler()
     formatter = logging.Formatter('%(asctime)s %(name)s %(levelname)s %(message)s')
     hdlr.setFormatter(formatter)
